@@ -42,18 +42,6 @@
 #include <math.h>
 #include <float.h>
 
-/*-----------------------------------------------------------------------------
-                                   Defines
- -----------------------------------------------------------------------------*/
-
-#if defined CPL_VERSION_CODE && CPL_VERSION_CODE >= CPL_VERSION(6, 3, 0)
-#define IRPLIB_FRAMESET_GET_CONST cpl_frameset_get_position_const
-#else
-/* Remove this branch once CPL versions less than 6.3 are no longer supported */
-#define IRPLIB_FRAMESET_GET_CONST cpl_frameset_get_frame_const
-#endif
-
-
 /*----------------------------------------------------------------------------*/
 /**
  * @defgroup irplib_stdstar     Functions for standard stars
@@ -119,7 +107,8 @@ irplib_stdstar_write_catalogs(cpl_frameset        *   set_in,
     /* Process the catalogs */
     for (i = 0; i < nb_catalogs; i++) {
         /* Get the catalog name */
-        const cpl_frame * cur_frame = IRPLIB_FRAMESET_GET_CONST(set_raw, i);
+        const cpl_frame * cur_frame = cpl_frameset_get_position_const(set_raw,
+                                                                      i);
         const char      * cat_name = cpl_frame_get_filename(cur_frame);
 
         cpl_table       * out = convert_ascii_table(cat_name);
@@ -335,15 +324,14 @@ cpl_error_code irplib_stdstar_check_columns_exist(
 
 /*----------------------------------------------------------------------------*/
 /**
-  @brief    Select the stars that are within a given distance
-  @param    cat     the catalog
-  @param    ra      RA pos
-  @param    dec     DEC pos
-  @param    dist    the distancw
-  @return   0 if ok, -1 in error case
+  @brief  Deselect the stars that are beyond a given distance
+  @param   cat   The standard star catalog, with too distant stars to unselect
+  @param   ra    Right ascension [degrees]
+  @param   dec   Declination [degrees]
+  @param   dist  The distance [degrees]
+  @return  0 if ok, -1 in error case
 
-  The stars that are within not further than dist from ra,dec are
-  selected in the table.
+  The stars that are further than dist from ra,dec are unselected in the table.
  */
 /*----------------------------------------------------------------------------*/
 int irplib_stdstar_select_stars_dist(
@@ -352,31 +340,34 @@ int irplib_stdstar_select_stars_dist(
         double          dec, 
         double          dist)
 {
-    double              distance;
-    int                 nrows;
-    int                 i;
+    cpl_size            i, nrows;
     
     /* Check entries */
     if (cat == NULL) return -1;
 
     /* Get the number of selected rows */
     nrows = cpl_table_get_nrow(cat);
-    
+
     /* Check if the columns are there */
     if (!cpl_table_has_column(cat, IRPLIB_STDSTAR_RA_COL)) {
-        cpl_msg_error(cpl_func, "Missing %s column", IRPLIB_STDSTAR_RA_COL);
+        cpl_msg_error(cpl_func, "Missing column: " IRPLIB_STDSTAR_RA_COL);
         return -1;
     }
     if (!cpl_table_has_column(cat, IRPLIB_STDSTAR_DEC_COL)) {
-        cpl_msg_error(cpl_func, "Missing %s column", IRPLIB_STDSTAR_DEC_COL);
+        cpl_msg_error(cpl_func, "Missing column: " IRPLIB_STDSTAR_DEC_COL);
+        return -1;
+    }
+    
+    if (cpl_table_count_selected(cat) == 0) {
+        cpl_msg_error(cpl_func, "All %d row(s) already deselected", (int)nrows);
         return -1;
     }
     
     /* Compute distances of the selected rows */
-    for (i=0; i<nrows; i++) {
+    for (i = 0; i < nrows; i++) {
         if (cpl_table_is_selected(cat, i)) {
             /* The row is selected - compute the distance */
-            distance = irplib_wcs_great_circle_dist(ra, dec, 
+            const double distance = irplib_wcs_great_circle_dist(ra, dec, 
                     cpl_table_get_double(cat, IRPLIB_STDSTAR_RA_COL, i, NULL),
                     cpl_table_get_double(cat, IRPLIB_STDSTAR_DEC_COL, i, NULL));            
             if (distance > dist) cpl_table_unselect_row(cat, i);
