@@ -1,3 +1,5 @@
+from __future__ import absolute_import
+from __future__ import print_function
 def log_invocation(fn='/tmp/reflex_invoc.log'):
     """ log invocation of actor for easy reexecution with:
         eval $(cat /tmp/reflex_invoc.log)
@@ -84,8 +86,8 @@ try:
         table = pipeline_product.PipelineProduct(frame_redl)
         wlen = table.all_hdu[0].header['ESO INS GRAT2 WLEN']
         is_simcal = table.all_hdu[0].header['ESO OCS SIMCAL']
-        print 'wlen=',wlen
-        print "is_simcal=",is_simcal
+        print('wlen=',wlen)
+        print("is_simcal=",is_simcal)
         if wlen == 520 :
            fibre_min=2
         if wlen == 580 :
@@ -203,10 +205,10 @@ This plot shows the distribution of detected arc lines on the wavelength calibra
 
 
     def plotScatterRESvsWAVE(self,fibre_id):
-      print "fibre_id=",fibre_id
+      print("fibre_id=",fibre_id)
       title = 'Wave Res: Mean=%#.3g Med=%#.3g RMS=%#.3g'% (self.list_line_tab[fibre_id].mean_all_residual,self.list_line_tab[fibre_id].median_all_residual,self.list_line_tab[fibre_id].std_all_residual) 
       self.title_res_wave=title
-      print "Mean=", self.list_line_tab[fibre_id].mean_all_residual
+      print("Mean=", self.list_line_tab[fibre_id].mean_all_residual)
       self.list_line_tab[fibre_id].plotRESvsWAVE(self.subplot_res_wave, title, self.tooltip_res_wave,fibre_id)
 
 
@@ -217,7 +219,7 @@ This plot shows the distribution of detected arc lines on the wavelength calibra
       self.list_line_tab[fibre_id].plotRESvsORDER(self.subplot_res_order, title, self.tooltip_res_order,fibre_id)
 
     def plotScatterFWHMvsWAVE(self,fibre_id):
-      print "fibere id", fibre_id
+      print("fibere id", fibre_id)
       title = 'FWHM: Mean=%#.3g Med=%#.3g RMS=%#.3g'% (self.list_line_tab[fibre_id].mean_all_fwhm,self.list_line_tab[fibre_id].median_all_fwhm,self.list_line_tab[fibre_id].std_all_fwhm) 
       self.title_fwhm_wave=title
 
@@ -284,7 +286,7 @@ In this window, the user should aim to improve the wavelength calibration soluti
 
 except ImportError:
   import_sucess = 'false'
-  print "Error importing modules pyfits, wx, matplotlib, numpy"
+  print("Error importing modules pyfits, wx, matplotlib, numpy")
 
 #This is the 'main' function
 if __name__ == '__main__':
