@@ -1,3 +1,5 @@
+from __future__ import absolute_import
+from __future__ import print_function
 try:
   import numpy
   import pipeline_display
@@ -43,15 +45,15 @@ class UvesBlueSpectrum:
       if mac_os :
           nwave = len(self.spectrum.flux)
           step = int (nwave / 1300 +0.5)
-          print "nwave=",nwave,"step=",step
-          print "Mac OS: spectrum resampled every",step,"pixels"
+          print("nwave=",nwave,"step=",step)
+          print("Mac OS: spectrum resampled every",step,"pixels")
           self.specdisp.display(subplot, title, tooltip, 
                                 self.spectrum.wave[::step], 
                                 self.spectrum.flux[::step], 
                                 self.spectrum_err.flux[::step], 
                                 autolimits=True)
       else :
-          print "Default OS"
+          print("Default OS")
           self.specdisp.display(subplot, title, tooltip, 
                                 self.spectrum.wave, 
                                 self.spectrum.flux, self.spectrum_err.flux, 
@@ -135,6 +137,80 @@ class ScatterPlot(Plot):
     subplot.set_xlim(0., numpy.nanmax(x) + 1.)
     subplot.set_ylim(0., 1.05 * numpy.nanmax(y))
 
+
+
+class PlotableResponseTable(ScatterPlot):
+  def __init__(self, fits):
+    self.table = pipeline_product.PipelineProduct(fits)
+    self.loadFromFits(self.table)
+
+  def loadFromFits(self, table) :
+    self.wave_smo        = table.all_hdu[1].data.field('wavelength')
+    self.resp_smo        = table.all_hdu[1].data.field('response_smo')
+    self.resp_smo_err    = table.all_hdu[1].data.field('response_smo_error')
+    self.resp_smo_bpm    = table.all_hdu[1].data.field('response_smo_bpm')
+
+    self.wave_raw        = table.all_hdu[2].data.field('wavelength')
+    self.resp_raw        = table.all_hdu[2].data.field('response_raw')
+    self.resp_raw_err    = table.all_hdu[2].data.field('response_raw_error')
+    self.resp_raw_bpm    = table.all_hdu[2].data.field('response_raw_bpm')
+
+    self.wave_fit_pts        = table.all_hdu[3].data.field('wavelength')
+    self.resp_fit_pts        = table.all_hdu[3].data.field('response_fit_pts')
+    self.resp_fit_pts_err    = table.all_hdu[3].data.field('response_fit_pts_error')
+    self.resp_fit_pts_bpm    = table.all_hdu[3].data.field('response_fit_pts_bpm')
+
+
+  def maxWaveSmo(self):
+    return numpy.nanmax(self.wave_smo)
+  def minWaveSmo(self):
+    return numpy.nanmin(self.wave_smo)
+
+  def maxWaveRaw(self):
+    return numpy.nanmax(self.wave_raw)
+  def minWaveRaw(self):
+    return numpy.nanmin(self.wave_raw)
+
+
+class PlotableBlueResponseTable(PlotableResponseTable):
+  def __init__(self, fits):
+    self.table = pipeline_product.PipelineProduct(fits)
+    self.loadFromFits(self.table)
+
+  def plotResponseRaw(self, subplot, title, tooltip):
+    print("min",self.minWaveRaw())
+    self.scatterPlot(subplot, self.wave_raw, self.resp_raw, 'Wavelength', 'Response [erg/e-/cm2]', title, tooltip)
+    self.scatterPlotScatterSmall(subplot, self.wave_smo, self.resp_smo,color_pt='green')
+    self.scatterPlotScatterSmall(subplot, self.wave_fit_pts, self.resp_fit_pts,color_pt='red')
+    subplot.set_xlim(self.minWaveRaw(), self.maxWaveRaw())
+    self.finalSetup(subplot, title, tooltip)
+
+class PlotableRedResponseTable(PlotableResponseTable):
+  def __init__(self, fits_low, fits_high):
+    self.resp_low         = PlotableResponseTable(fits_low)
+    self.resp_high        = PlotableResponseTable(fits_high)
+    #self.order_high_shift  = self.order_high.order_raw + self.order_low.maxOrder()
+    #self.max_total_order   = numpy.nanmax(self.order_high_shift)
+
+  def plotResponseRaw(self, subplot, title, tooltip):
+    #self.plotLowHiTextBottom(subplot)
+    self.setLabels(subplot, 'Wavelength', 'Response [erg/e-/cm2]')
+    self.scatterPlot(subplot, self.resp_low.wave_raw, self.resp_low.resp_raw, 'Wavelength', 'Response [erg/e-/cm2]', title, tooltip)
+    self.scatterPlotScatterSmall(subplot, self.resp_low.wave_smo, self.resp_low.resp_smo,color_pt='green')
+    self.scatterPlotScatterSmall(subplot, self.resp_low.wave_fit_pts, self.resp_low.resp_fit_pts,color_pt='red')
+    #subplot.set_xlim(self.resp_low.minWaveRaw(), self.resp_high.maxWaveRaw())
+
+    
+    self.scatterPlot(subplot, self.resp_high.wave_raw, self.resp_high.resp_raw, 'Wavelength', 'Response [erg/e-/cm2]', title, tooltip)
+    self.scatterPlotScatterSmall(subplot, self.resp_high.wave_smo, self.resp_high.resp_smo,color_pt='green')
+    self.scatterPlotScatterSmall(subplot, self.resp_high.wave_fit_pts, self.resp_high.resp_fit_pts,color_pt='red')
+    subplot.set_xlim(self.resp_low.minWaveRaw(), self.resp_high.maxWaveRaw())
+
+    #subplot.set_ylim(0., 1.05 * max(self.order_low.maxSN(), self.order_high.maxSN()))
+    #self.plotLowHiSepLine(subplot)
+    self.finalSetup(subplot, title, tooltip)
+
+    
 class PlotableOrderTable(ScatterPlot):
   def __init__(self, fits):
     self.table = pipeline_product.PipelineProduct(fits)
@@ -174,6 +250,7 @@ class PlotableOrderTable(ScatterPlot):
   def minLinepos(self):
     return numpy.nanmin(self.pos_raw)
 
+
 class PlotableBlueOrderTable(PlotableOrderTable):
   def __init__(self, fits):
     self.table = pipeline_product.PipelineProduct(fits)
