@@ -62,7 +62,7 @@ flames_reduce_vcorrel(const char* sci_pfx,
 
    int ord = 0;
    int ord_min=1;
-   char cvel_tab_name[80];
+   char cvel_tab_name[MAX_NAME_SIZE];
    char tim_ccf[80];
    char nim_ccf[80];
    char iim_pfx[80];
