@@ -388,7 +388,9 @@ static int test_main(void)
         cpl_property *prop = cpl_propertylist_get(plist, i);
 
         cx_assert(!strcmp(cpl_property_get_name(prop), keys[i]));
-        cx_assert(!strcmp(cpl_property_get_comment(prop), comments[i]));
+        if(cpl_property_get_comment(prop) != NULL ) {
+           cx_assert(!strcmp(cpl_property_get_comment(prop), comments[i]));
+        }
         cx_assert(cpl_property_get_type(prop) == types[i]);
 
         cx_assert(my_uves_propertylist_contains(plist, keys[i]));
@@ -937,7 +939,7 @@ static int test_main(void)
             s = hdr[i].key + strlen("HIERARCH") + 1;
 
         cx_assert(!strcmp(cpl_property_get_name(p), s));
-        cx_assert(hdr[i].com == NULL ||
+        cx_assert(hdr[i].com == NULL || cpl_property_get_comment(p) == NULL ||
                   !strcmp(cpl_property_get_comment(p), hdr[i].com));
         cx_assert(cpl_property_get_type(p) == hdr[i].type);
 
@@ -1004,8 +1006,10 @@ static int test_main(void)
 
         cx_assert(strcmp(cpl_property_get_name(p),
                          cpl_property_get_name(_p)) == 0);
-        cx_assert(strcmp(cpl_property_get_comment(p),
-                         cpl_property_get_comment(_p)) == 0);
+                         if(cpl_property_get_comment(p) != NULL && cpl_property_get_comment(_p) != NULL) {
+                            cx_assert(strcmp(cpl_property_get_comment(p),
+                             cpl_property_get_comment(_p)) == 0);
+                         }
         cx_assert(cpl_property_get_type(p) == cpl_property_get_type(_p));
 
         switch (cpl_property_get_type(p)) {
@@ -1235,7 +1239,9 @@ static int test_main(void)
         cpl_property *prop = cpl_propertylist_get(plist, i);
 
         cx_assert(!strcmp(cpl_property_get_name(prop), keys[i]));
-        cx_assert(!strcmp(cpl_property_get_comment(prop), comments[i]));
+        if(cpl_property_get_comment(prop) != NULL ) {
+            cx_assert(!strcmp(cpl_property_get_comment(prop), comments[i]));
+        }
         cx_assert(cpl_property_get_type(prop) == types[i]);
 
         cx_assert(my_uves_propertylist_contains(plist, keys[i]));
