@@ -252,6 +252,17 @@ uves_cd_align_process(const cpl_image *im1,
     cpl_table_new_column(result, "BACK2", CPL_TYPE_DOUBLE);
     cpl_table_new_column(result, "NORM1", CPL_TYPE_DOUBLE);
     cpl_table_new_column(result, "NORM2", CPL_TYPE_DOUBLE);
+
+    cpl_table_set_column_unit(result,"X","pix");
+    cpl_table_set_column_unit(result,"YCEN1","pix");
+    cpl_table_set_column_unit(result,"YCEN2","pix");
+    cpl_table_set_column_unit(result,"SIGMA1","pix");
+    cpl_table_set_column_unit(result,"SIGMA2","pix");
+    cpl_table_set_column_unit(result,"BACK1","ADU");
+    cpl_table_set_column_unit(result,"BACK2","ADU");
+    cpl_table_set_column_unit(result,"NORM1","ADU");
+    cpl_table_set_column_unit(result,"NORM2","ADU");
+
     assure_mem( result );
     
     /* Find row of max accumulated flux (i.e. position of the order) */
@@ -333,7 +344,7 @@ uves_cd_align_process(const cpl_image *im1,
     check(( cpl_table_duplicate_column(result, "YDIFF", result, "YCEN2"),
         cpl_table_subtract_columns(result, "YDIFF", "YCEN1")),
       "Error calculating residuals of fit");
-
+    cpl_table_set_column_unit(result,"YDIFF","pix");
     {
     cpl_size num_valid = cpl_table_get_nrow(result) - cpl_table_count_invalid(result, "YDIFF");
     
@@ -484,6 +495,7 @@ uves_cal_cd_align_exe(cpl_frameset *frames, const cpl_parameterlist *parameters,
 
     /* Output */
     uves_propertylist *product_header = NULL;
+    uves_propertylist *table_header = NULL;
     cpl_table *cd_align = NULL;
     
     /* Parameters */
@@ -573,6 +585,7 @@ uves_cal_cd_align_exe(cpl_frameset *frames, const cpl_parameterlist *parameters,
        "Could not compute QC");
 
     product_header = uves_propertylist_new();
+
     product_filename = uves_cd_align_filename(chip);
     check( uves_frameset_insert(frames,
                 cd_align,
