@@ -67,6 +67,24 @@
 #define TELESCOPE_EFFECTIVE_AREA   \
   (M_PI * (PRIMARY_DIA * PRIMARY_DIA - OBSTR_DIA * OBSTR_DIA) / 4.0)  /* (cm^2) */
 
+
+
+static cpl_boolean
+uves_is_new_flux_std(uves_propertylist* plist){
+	cpl_boolean result=CPL_FALSE;
+	const char* targ_name = uves_pfits_get_targ_name(plist);
+	if(  strcmp(targ_name,"GD71") == 0 ||
+			strcmp(targ_name,"GD153") == 0 ||
+			strcmp(targ_name,"LTT3218") == 0 ||
+			strcmp(targ_name,"LTT7987") == 0 ||
+			strcmp(targ_name,"Feige110") == 0 ||
+			strcmp(targ_name,"EG21") == 0 ||
+			strcmp(targ_name,"EG274") == 0 )
+	{
+		result=CPL_TRUE;
+	}
+	return result;
+}
 /**@{*/
 /**
   @brief    Calculate quantum detection efficiency
@@ -342,6 +360,11 @@ uves_response_efficiency(const cpl_image *raw_image,
     cpl_table_new_column(*efficiency, "Eff", CPL_TYPE_DOUBLE);
     cpl_table_new_column(*efficiency, "Binsize", CPL_TYPE_DOUBLE);
     cpl_table_new_column(*efficiency, "Order", CPL_TYPE_INT);
+    cpl_table_set_column_unit(*efficiency,"Wave","Angstrom");
+    cpl_table_set_column_unit(*efficiency,"Eff"," ");
+    cpl_table_set_column_unit(*efficiency,"Binsize","Angstrom");
+    cpl_table_set_column_unit(*efficiency,"Order"," ");
+    cpl_boolean is_new_flux_std = uves_is_new_flux_std(raw_header);
     row = 0;
     
     check( first_abs_order = uves_pfits_get_firstabsorder(linetable_header[1]), 
@@ -446,13 +469,25 @@ uves_response_efficiency(const cpl_image *raw_image,
                     nx, abs_order, 1) / abs_order) * weight,
                    "Could not evaluate dispersion relation");
             */
-
+            /* OLD IMPLEMENTATION ASSUMIN OLD FLUX STD UNITS in 10^-16 (Jansky) */
+            /*
+            if (!is_new_flux_std ) {//1e-10
             flux = flux * 1e16 * 1e17 * H_BAR * SPEED_OF_LIGHT /
                 (dldx * lambda * TELESCOPE_EFFECTIVE_AREA);
+            }
+            */
+
+
+            	flux = flux  * 1e17 * H_BAR * SPEED_OF_LIGHT /
+            	                (dldx * lambda * TELESCOPE_EFFECTIVE_AREA);
+
+
             /* The factor 1e17 accounts for the conversion Joule<-erg
              * (10^7) and Angstrom->meters (10^10)
              * The factor 1e16 is to correct for the fact that the
              * catalogue flux is in units of (10^-16 <standard units>)
+             * With new catalog (after HDRL upgrade) the factor 1e16
+             * should not be applied
              */
 
             if (noise < 3*average_noise)
@@ -520,12 +555,12 @@ uves_response_efficiency(const cpl_image *raw_image,
         
         uves_msg_debug("%" CPL_SIZE_FORMAT " bins in central 20 %% range of order #%d",
                    cpl_table_count_selected(*efficiency), order);
-        
+
         if ( cpl_table_count_selected(*efficiency) > 0)
             {
             uves_free_table(&central_efficiency);
             central_efficiency = cpl_table_extract_selected(*efficiency);
-            
+
             /* Get 90% percentile efficiency */
             uves_sort_table_1(central_efficiency, "Eff", false);     /* Ascending */
             
