@@ -231,7 +231,7 @@ uves_error_fraction(double x, double y, double dx, double dy)
     return sqrt( dx*dx/(y*y) + x*x*dy*dy/(y*y*y*y) );
 }
 
-
+int uves_print_rec_status(const int val);
 const char *uves_get_license(void);
 cpl_error_code uves_get_version(int *major, int *minor, int *micro);
 int uves_get_version_binary(void);
@@ -239,7 +239,8 @@ int uves_get_version_binary(void);
 char * uves_initialize(cpl_frameset *frames, const cpl_parameterlist *parlist, 
                const char *recipe_id, const char *short_descr);
 cpl_error_code uves_end(const char *recipe_id, const cpl_frameset *frames);
-
+cpl_error_code
+uves_table_add_extname(const char* fname,const char* xvalue,const int x_num);
 uves_propertylist *uves_initialize_image_header(const char *ctype1, const char *ctype2, const char *cunit1, const char *cunit2, 
                            const char *bunit,const double bscale,
                            double crval1 , double crval2,
